@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Glorified metronome
 
-our $VERSION = '0.3001';
+our $VERSION = '0.3002';
 
 use Math::Bezier ();
 use MIDI::Util qw(dura_size set_chan_patch set_time_signature);
@@ -413,6 +413,25 @@ sub pattern {
 }
 
 
+sub sync_patterns {
+    my ($self, %patterns) = @_;
+
+    my $duration = delete $patterns{duration} || $self->quarter;
+
+    my @subs;
+    for my $instrument (keys %patterns) {
+        push @subs, sub {
+            $self->pattern(
+                instrument => $instrument,
+                patterns   => $patterns{$instrument},
+                duration   => $duration,
+            );
+        },
+    }
+
+    $self->sync(@subs);
+}
+
 
 sub set_time_sig {
     my ($self, $signature, $set) = @_;
@@ -452,7 +471,7 @@ MIDI::Drummer::Tiny - Glorified metronome
 
 =head1 VERSION
 
-version 0.3001
+version 0.3002
 
 =head1 SYNOPSIS
 
@@ -490,10 +509,10 @@ version 0.3001
     for 1 .. $d->beats * $d->bars;
 
  # Same but with beat-strings:
- $d->sync(
-    sub { $d->pattern( instrument => $d->open_hh, patterns => [ ('1111') x $d->bars ] ) },
-    sub { $d->pattern( instrument => $d->snare,   patterns => [ ('0101') x $d->bars ] ) },
-    sub { $d->pattern( instrument => $d->kick,    patterns => [ ('1010') x $d->bars ] ) },
+ $d->sync_patterns(
+    $d->open_hh => [ ('1111') x $d->bars ],
+    $d->snare   => [ ('0101') x $d->bars ],
+    $d->kick    => [ ('1010') x $d->bars ],
  );
 
  $d->write;
@@ -816,15 +835,31 @@ Defaults:
   instrument: snare
   patterns: [] (i.e. empty!)
   Options:
-    duration: 1 (quarter-note)
+    duration: quarter-note
     beats: given by constructor
-    repeat: 4
-    count: 0
-    negate: 0
+    repeat: 1
+    count: 0 ( keep track of the beat count)
+    negate: 0 (flip the bit values)
     vary:
         0 => sub { $self->rest( $args{duration} ) },
         1 => sub { $self->note( $args{duration}, $args{instrument} ) },
 
+=head2 sync_patterns
+
+  $d->sync_patterns( $instrument1 => $patterns1, $inst2 => $pats2, ..., %options );
+  $d->sync_patterns(
+      duration    => $d->eighth,
+      $d->open_hh => [ ('11111111') x $d->bars ],
+      $d->snare   => [ ('00100010') x $d->bars ],
+      $d->kick    => [ ('10001100') x $d->bars ],
+  );
+
+Execute the C<patterns> method for multiple voices.
+
+Option defaults:
+
+  duration: quarter-note
+
 =head2 set_time_sig
 
   $d->set_time_sig;
